@@ -11,7 +11,7 @@ import socket
 import hashlib
 import time
 import errno
-import osm_handling_config
+import osm_handling_config.global_config
 
 def wikidata_url(wikidata_id):
     return "https://www.wikidata.org/wiki/" + wikidata_id
@@ -42,7 +42,7 @@ def download(url, timeout=360):
                 url, 
                 data=None, 
                 headers={
-                    'User-Agent': osm_handling_config.get_user_agent()
+                    'User-Agent': osm_handling_config.global_config.get_user_agent()
                 }
             )
             f = urllib.request.urlopen(url, timeout=timeout)
